@@ -26,8 +26,8 @@ class SbModel:
         self.model_id = f'{model_name}{self.separator}{model_version}'
         self.input_prep = input_prep
         self.model_name = model_name
-        self.input_train_path = f'{model_name}/input_data/train'
-        self.input_predict_path = f'{model_name}/input_data/predict'
+        self.input_train_path = f'{model_name}/input_data/train/train'
+        self.input_predict_path = f'{model_name}/input_data/predict/predict'
         self.output_path = f'{model_name}/output_data'
         self.model_path = f'{model_name}/model'
         self.bucket = bucket
